==> zio-aws-imagebuilder_2.13-5.17.203.2-sources.jar: zio/aws/imagebuilder/model/ListImagesRequest.scala <==
package zio.aws.imagebuilder.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.imagebuilder.model.primitives.{
  NullableBoolean,
  PaginationToken,
  RestrictedInteger
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListImagesRequest(
    owner: Optional[zio.aws.imagebuilder.model.Ownership] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.imagebuilder.model.Filter]] =
      Optional.Absent,
    byName: Optional[Boolean] = Optional.Absent,
    maxResults: Optional[RestrictedInteger] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent,
    includeDeprecated: Optional[NullableBoolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest = {
    import ListImagesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest
      .builder()
      .optionallyWith(owner.map(value => value.unwrap))(_.owner)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(byName.map(value => value: java.lang.Boolean))(_.byName)
      .optionallyWith(
        maxResults.map(value => RestrictedInteger.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(includeDeprecated.map(value => value: java.lang.Boolean))(
        _.includeDeprecated
      )
      .build()
  }
  def asReadOnly: zio.aws.imagebuilder.model.ListImagesRequest.ReadOnly =
    zio.aws.imagebuilder.model.ListImagesRequest.wrap(buildAwsValue())
}
object ListImagesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.ListImagesRequest =
      zio.aws.imagebuilder.model.ListImagesRequest(
        owner.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        byName.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value),
        includeDeprecated.map(value => value)
      )
    def owner: Optional[zio.aws.imagebuilder.model.Ownership]
    def filters: Optional[List[zio.aws.imagebuilder.model.Filter.ReadOnly]]
    def byName: Optional[Boolean]
    def maxResults: Optional[RestrictedInteger]
    def nextToken: Optional[PaginationToken]
    def includeDeprecated: Optional[NullableBoolean]
    def getOwner: ZIO[Any, AwsError, zio.aws.imagebuilder.model.Ownership] =
      AwsError.unwrapOptionField("owner", owner)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.imagebuilder.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getByName: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("byName", byName)
    def getMaxResults: ZIO[Any, AwsError, RestrictedInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getIncludeDeprecated: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField("includeDeprecated", includeDeprecated)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest
  ) extends zio.aws.imagebuilder.model.ListImagesRequest.ReadOnly {
    override val owner: Optional[zio.aws.imagebuilder.model.Ownership] =
      zio.aws.core.internal
        .optionalFromNullable(impl.owner())
        .map(value => zio.aws.imagebuilder.model.Ownership.wrap(value))
    override val filters
        : Optional[List[zio.aws.imagebuilder.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.imagebuilder.model.Filter.wrap(item)
          }.toList
        )
    override val byName: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.byName())
      .map(value => value: Boolean)
    override val maxResults: Optional[RestrictedInteger] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.RestrictedInteger(value)
      )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.PaginationToken(value)
      )
    override val includeDeprecated: Optional[NullableBoolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.includeDeprecated())
        .map(value => value: NullableBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest
  ): zio.aws.imagebuilder.model.ListImagesRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-imagebuilder_3-7.31.0.1-sources.jar: zio/aws/imagebuilder/model/ListImagesRequest.scala <==
package zio.aws.imagebuilder.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.imagebuilder.model.primitives.{
  NullableBoolean,
  PaginationToken,
  RestrictedInteger
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListImagesRequest(
    owner: Optional[zio.aws.imagebuilder.model.Ownership] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.imagebuilder.model.Filter]] =
      Optional.Absent,
    byName: Optional[Boolean] = Optional.Absent,
    maxResults: Optional[RestrictedInteger] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent,
    includeDeprecated: Optional[NullableBoolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest = {
    import ListImagesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest
      .builder()
      .optionallyWith(owner.map(value => value.unwrap))(_.owner)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(byName.map(value => value: java.lang.Boolean))(_.byName)
      .optionallyWith(
        maxResults.map(value => RestrictedInteger.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(includeDeprecated.map(value => value: java.lang.Boolean))(
        _.includeDeprecated
      )
      .build()
  }
  def asReadOnly: zio.aws.imagebuilder.model.ListImagesRequest.ReadOnly =
    zio.aws.imagebuilder.model.ListImagesRequest.wrap(buildAwsValue())
}
object ListImagesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.ListImagesRequest =
      zio.aws.imagebuilder.model.ListImagesRequest(
        owner.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        byName.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value),
        includeDeprecated.map(value => value)
      )
    def owner: Optional[zio.aws.imagebuilder.model.Ownership]
    def filters: Optional[List[zio.aws.imagebuilder.model.Filter.ReadOnly]]
    def byName: Optional[Boolean]
    def maxResults: Optional[RestrictedInteger]
    def nextToken: Optional[PaginationToken]
    def includeDeprecated: Optional[NullableBoolean]
    def getOwner: ZIO[Any, AwsError, zio.aws.imagebuilder.model.Ownership] =
      AwsError.unwrapOptionField("owner", owner)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.imagebuilder.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getByName: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("byName", byName)
    def getMaxResults: ZIO[Any, AwsError, RestrictedInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getIncludeDeprecated: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField("includeDeprecated", includeDeprecated)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest
  ) extends zio.aws.imagebuilder.model.ListImagesRequest.ReadOnly {
    override val owner: Optional[zio.aws.imagebuilder.model.Ownership] =
      zio.aws.core.internal
        .optionalFromNullable(impl.owner())
        .map(value => zio.aws.imagebuilder.model.Ownership.wrap(value))
    override val filters
        : Optional[List[zio.aws.imagebuilder.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.imagebuilder.model.Filter.wrap(item)
          }.toList
        )
    override val byName: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.byName())
      .map(value => value: Boolean)
    override val maxResults: Optional[RestrictedInteger] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.RestrictedInteger(value)
      )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.PaginationToken(value)
      )
    override val includeDeprecated: Optional[NullableBoolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.includeDeprecated())
        .map(value => value: NullableBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.ListImagesRequest
  ): zio.aws.imagebuilder.model.ListImagesRequest.ReadOnly = new Wrapper(impl)
}
